@@ -11,7 +11,6 @@
 #    under the License.
 
 
-from oslo_log import versionutils
 from oslo_policy import policy
 
 from placement.policies import base
@@ -25,36 +24,10 @@ ALLOC_MANAGE = ALLOC_PREFIX % 'manage'
 ALLOC_UPDATE = ALLOC_PREFIX % 'update'
 ALLOC_DELETE = ALLOC_PREFIX % 'delete'
 
-DEPRECATED_REASON = """
-The allocation API now supports read-only roles by default.
-"""
-
-deprecated_manage_allocations = policy.DeprecatedRule(
-    name=ALLOC_MANAGE,
-    check_str=base.RULE_ADMIN_API
-)
-deprecated_list_allocation = policy.DeprecatedRule(
-    name=ALLOC_LIST,
-    check_str=base.RULE_ADMIN_API
-)
-deprecated_update_allocation = policy.DeprecatedRule(
-    name=ALLOC_UPDATE,
-    check_str=base.RULE_ADMIN_API
-)
-deprecated_delete_allocation = policy.DeprecatedRule(
-    name=ALLOC_DELETE,
-    check_str=base.RULE_ADMIN_API
-)
-deprecated_list_resource_provider_allocations = policy.DeprecatedRule(
-    name=RP_ALLOC_LIST,
-    check_str=base.RULE_ADMIN_API,
-)
-
-
 rules = [
     policy.DocumentedRuleDefault(
         name=ALLOC_MANAGE,
-        check_str=base.SYSTEM_ADMIN,
+        check_str=base.ADMIN_OR_SERVICE,
         description="Manage allocations.",
         operations=[
             {
@@ -62,14 +35,11 @@ rules = [
                 'path': '/allocations'
             }
         ],
-        scope_types=['system'],
-        deprecated_rule=deprecated_manage_allocations,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        scope_types=['project'],
     ),
     policy.DocumentedRuleDefault(
         name=ALLOC_LIST,
-        check_str=base.SYSTEM_READER,
+        check_str=base.ADMIN_OR_SERVICE,
         description="List allocations.",
         operations=[
             {
@@ -77,14 +47,11 @@ rules = [
                 'path': '/allocations/{consumer_uuid}'
             }
         ],
-        scope_types=['system'],
-        deprecated_rule=deprecated_list_allocation,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        scope_types=['project'],
     ),
     policy.DocumentedRuleDefault(
         name=ALLOC_UPDATE,
-        check_str=base.SYSTEM_ADMIN,
+        check_str=base.ADMIN_OR_SERVICE,
         description="Update allocations.",
         operations=[
             {
@@ -92,14 +59,11 @@ rules = [
                 'path': '/allocations/{consumer_uuid}'
             }
         ],
-        scope_types=['system'],
-        deprecated_rule=deprecated_update_allocation,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        scope_types=['project'],
     ),
     policy.DocumentedRuleDefault(
         name=ALLOC_DELETE,
-        check_str=base.SYSTEM_ADMIN,
+        check_str=base.ADMIN_OR_SERVICE,
         description="Delete allocations.",
         operations=[
             {
@@ -107,14 +71,11 @@ rules = [
                 'path': '/allocations/{consumer_uuid}'
             }
         ],
-        scope_types=['system'],
-        deprecated_rule=deprecated_delete_allocation,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        scope_types=['project'],
     ),
     policy.DocumentedRuleDefault(
         name=RP_ALLOC_LIST,
-        check_str=base.SYSTEM_READER,
+        check_str=base.ADMIN_OR_SERVICE,
         description="List resource provider allocations.",
         operations=[
             {
@@ -122,10 +83,7 @@ rules = [
                 'path': '/resource_providers/{uuid}/allocations'
             }
         ],
-        scope_types=['system'],
-        deprecated_rule=deprecated_list_resource_provider_allocations,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        scope_types=['project'],
     ),
 ]
 
